#ifndef LIBGNOMEUI_H
#define LIBGNOMEUI_H

#include "libgnome/gnome-defs.h"
#include "libgnomeui/gnome-app.h"
#include "libgnomeui/gnome-app-helper.h"
#include "libgnomeui/gnome-actionarea.h"
#include "libgnomeui/gnome-colors.h"
#include "libgnomeui/gnome-color-selector.h"
#include "libgnomeui/gnome-messagebox.h"
#include "libgnomeui/gnome-pixmap.h"
#include "libgnomeui/gnome-actionarea.h"
#include "libgnomeui/gnome-scores.h"
#include "libgnomeui/gnome-stock.h"
#include "libgnomeui/gtk-clock.h"

BEGIN_GNOME_DECLS

void gnome_init (int *argc, char ***argv);

END_GNOME_DECLS

#endif
